NodePieceRepresentation
=======================

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: NodePieceRepresentation
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~NodePieceRepresentation.extra_repr

   .. rubric:: Methods Documentation

   .. automethod:: extra_repr
